"use strict";
this.name        = "stations_for_extra_planets"; 
this.author      = "spara"; 
this.copyright   = "2013-2014 Mika Spara";
this.licence     = "CC BY-NC-SA 3.0"; 
this.description = "Add stations to extra planets"; 
this.version     = "1.7";

//fiksaa buoy koodit kuntoon

//1.7 upgraded for Oolite 1.79. depends on additional planets oxp
//1.6 zieman habitat added to the mix
//1.5 solidate station added to the mix
//1.4.1 bugfixed station name
//1.4 buoys beaconCodes named after stations to provide compatibility with milhud and other oxps that rely on buoy beaconCodes.
//1.3 trade outpost added to the mix
//1.2.1 bugfixing station positioning
//1.2 moved stations to random position
//1.2 made buoys tumble
//1.1 reworked distribution of types
//1.1 added new cargoes to extra stations
//1.1 massive rework on shipdata
//1.1 correct scanclass for buoys

this.$corStations = ["sfep_pag_coriolis1", "sfep_pag_coriolis2", "sfep_pag_coriolis3", "sfep_pag_coriolis4", "sfep_pag_coriolis5", "sfep_pag_coriolis6", "sfep_l", "sfep_m", "sfep_s", "sfep_trade_outpost"];//10 stations
this.$dodStations =["sfep_pag_dodecahedron1", "sfep_pag_dodecahedron2", "sfep_pag_dodecahedron3", "sfep_pag_dodecahedron4", "sfep_xl", "sfep_kev1", "sfep_kev2", "sfep_kev3"];//8 stations
this.$icoStations = ["sfep_globestation", "sfep_globestationxl", "sfep_toriA", "sfep_toriB", "sfep_pag_icosahedron1", "sfep_pag_icosahedron2", "sfep_pag_icosahedron3", "sfep_pag_icosahedron4", "sfep_xxl", "sfep_sodalite", "sfep_habmk2"];//11 stations

this.startUp = function() {
	//register stations to have default markets of new cargoes
	if (worldScripts.CargoTypeExtension)
		worldScripts["CargoTypeExtension"].registerOXPStation("CargoTypeExtension-DefaultMarket","sfep_station");
};

//additional planets oxp calls this at the start of the populate.
this.initStationArray = function() {
	//match extra stations' types to main station type.
	if (system.techLevel < 11)
		this.$stations = this.$corStations.concat();
	else 
		this.$stations = this.$corStations.concat(this.$dodStations, this.$icoStations);
}

//public function to set station populator. Call with planet coordinates and radius
this.setStationPopulator = function(coords, radius, index) {
	//sanity check of the array
	if (this.$stations.length === 0) return;
	
	//choose station
	var stationInd = Math.floor(system.scrambledPseudoRandomNumber(coords[0]) * this.$stations.length);
	
	//check station validator for possible deaths.
	if (worldScripts.station_validator && (worldScripts.station_validator.$deaths(this.$stations[stationInd]).length !== 0))
		return;
		
	//add station to a random location around the planet
	var polar = Math.PI * system.scrambledPseudoRandomNumber(coords[0]);
	var azimuth = 2.0 * Math.PI * system.scrambledPseudoRandomNumber(coords[1]);
	var directionV = Vector3D(Math.sin(polar) * Math.cos(azimuth), Math.sin(polar) * Math.sin(azimuth), Math.cos(polar));

	//prevent the same station appearing multiple times in one system
	var stationRole = this.$stations.splice(stationInd, 1);

	system.setPopulator("sfep_"+ (coords[0] + coords[1]), {
		callback: function(pos) {
			var addedStation = system.addShips(stationRole, 1, pos, 0)[0];
			
			//orientate station dock to the planet just like main station
			var targetVector = coords.subtract(pos ).direction();
			var angle = addedStation.heading.angleTo(targetVector);
			var cross = addedStation.heading.cross(targetVector).direction();
			addedStation.orientation = addedStation.orientation.rotate(cross, -angle);
			
			//add navigation buoy
			var addedBuoy = system.addShips("buoy", 1, addedStation.position.add(addedStation.heading.multiply(10E3)),0)[0];
			addedBuoy.scanClass = "CLASS_BUOY";
			addedBuoy.displayName = addedStation.displayName + " Buoy";
			addedBuoy.beaconCode = "N - " + addedBuoy.displayName;
			addedBuoy.setAI("dumbAI.plist");
			addedBuoy.beaconLabel = addedStation.displayName;

		}.bind(this),
		location: "COORDINATES",
		coordinates: coords.add(directionV.multiply(2 * radius)),
		deterministic: true,
		priority: 102
	});
}
